@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -17,13 +17,14 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
+class Horde_Imap_Client_Cache_Backend_Db
+extends Horde_Imap_Client_Cache_Backend
 {
-    /* Table names. */
+    /** SQL table names. */
     const BASE_TABLE = 'horde_imap_client_data';
     const MD_TABLE = 'horde_imap_client_metadata';
     const MSG_TABLE = 'horde_imap_client_message';
@@ -39,16 +40,10 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
      * Constructor.
      *
      * @param array $params  Configuration parameters:
-     * <ul>
-     *  <li>
-     *   REQUIRED Parameters:
-     *   <ul>
-     *    <li>
-     *     db: (Horde_Db_Adapter) DB object.
-     *    </li>
-     *   </ul>
-     *  </li>
-     * </ul>
+     * <pre>
+     *   - REQUIRED Parameters:
+     *     - db: (Horde_Db_Adapter) DB object.
+     * </pre>
      */
     public function __construct(array $params = array())
     {
@@ -90,9 +85,11 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
             $res = $this->_db->select($query[0], $query[1]);
 
             foreach ($res as $row) {
-                $out[$row['msguid']] = @unserialize($compress->decompress(
-                    $columns['data']->binaryToString($row['data'])
-                ));
+                try {
+                    $out[$row['msguid']] = @unserialize($compress->decompress(
+                        $columns['data']->binaryToString($row['data'])
+                    ));
+                } catch (Exception $e) {}
             }
         } catch (Horde_Db_Exception $e) {}
 
@@ -133,7 +130,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
                 try {
                     /* Update */
                     $this->_db->update(
-                        sprintf('UPDATE %s SET data = ? WHERE uid = ? AND msguid = ?', self::MSG_TABLE),
+                        sprintf('UPDATE %s SET data = ? WHERE messageid = ? AND msguid = ?', self::MSG_TABLE),
                         array(
                             new Horde_Db_Value_Binary($compress->compress(serialize(array_merge($res[$key], $val)))),
                             $uid,
@@ -145,7 +142,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
                 /* Insert */
                 try {
                     $this->_db->insert(
-                        sprintf('INSERT INTO %s (data, msguid, uid) VALUES (?, ?, ?)', self::MSG_TABLE),
+                        sprintf('INSERT INTO %s (data, msguid, messageid) VALUES (?, ?, ?)', self::MSG_TABLE),
                         array(
                             new Horde_Db_Value_Binary($compress->compress(serialize($val))),
                             strval($key),
@@ -160,7 +157,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
         try {
             $this->_db->update(
                 sprintf(
-                    'UPDATE %s SET modified = ? WHERE uid = ?',
+                    'UPDATE %s SET modified = ? WHERE messageid = ?',
                     self::BASE_TABLE
                 ),
                 array(time(), $uid)
@@ -199,9 +196,11 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
                         break;
 
                     default:
-                        $res[$key] = @unserialize(
-                            $columns['data']->binaryToString($val)
-                        );
+                        try {
+                            $res[$key] = @unserialize(
+                                $columns['data']->binaryToString($val)
+                            );
+                        } catch (Exception $e) {}
                         break;
                     }
                 }
@@ -227,7 +226,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
             $uid = $this->_createUid($mailbox);
         }
 
-        $query = sprintf('SELECT field FROM %s where uid = ?', self::MD_TABLE);
+        $query = sprintf('SELECT field FROM %s where messageid = ?', self::MD_TABLE);
         $values = array($uid);
 
         try {
@@ -244,7 +243,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
                 try {
                     $this->_db->update(
                         sprintf(
-                            'UPDATE %s SET data = ? WHERE field = ? AND uid = ?',
+                            'UPDATE %s SET data = ? WHERE field = ? AND messageid = ?',
                             self::MD_TABLE
                         ),
                         array($val, $key, $uid)
@@ -255,7 +254,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
                 try {
                     $this->_db->insert(
                         sprintf(
-                            'INSERT INTO %s (data, field, uid) VALUES (?, ?, ?)',
+                            'INSERT INTO %s (data, field, messageid) VALUES (?, ?, ?)',
                             self::MD_TABLE
                         ),
                         array($val, $key, $uid)
@@ -269,9 +268,13 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
      */
     public function deleteMsgs($mailbox, $uids)
     {
+        if (empty($uids)) {
+            return;
+        }
+
         $query = $this->_baseSql($mailbox);
         $query[0] = sprintf(
-            'DELETE FROM %s WHERE uid IN (SELECT uid ' . $query[0] . ')',
+            'DELETE FROM %s WHERE messageid IN (SELECT messageid ' . $query[0] . ')',
             self::MSG_TABLE
         );
 
@@ -298,7 +301,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
         foreach (array(self::BASE_TABLE, self::MD_TABLE, self::MSG_TABLE) as $val) {
             try {
                 $this->_db->delete(
-                    sprintf('DELETE FROM %s WHERE uid = ?', $val),
+                    sprintf('DELETE FROM %s WHERE messageid = ?', $val),
                     array($uid)
                 );
             } catch (Horde_Db_Exception $e) {}
@@ -319,7 +322,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
         }
 
         $purge = time() - $lifetime;
-        $sql = 'DELETE FROM %s WHERE uid IN (SELECT uid FROM %s WHERE modified < ?';
+        $sql = 'DELETE FROM %s WHERE messageid IN (SELECT messageid FROM %s WHERE modified < ?';
 
         foreach (array(self::MD_TABLE, self::MSG_TABLE) as $val) {
             try {
@@ -351,7 +354,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
         $sql = sprintf('FROM %s d', self::BASE_TABLE);
 
         if (!is_null($join)) {
-            $sql .= sprintf(' INNER JOIN %s t ON d.uid = t.uid', $join);
+            $sql .= sprintf(' INNER JOIN %s t ON d.messageid = t.messageid', $join);
         }
 
         return array(
@@ -373,7 +376,7 @@ class Horde_Imap_Client_Cache_Backend_Db extends Horde_Imap_Client_Cache_Backend
     protected function _getUid($mailbox)
     {
         $query = $this->_baseSql($mailbox);
-        $query[0] = 'SELECT d.uid ' . $query[0];
+        $query[0] = 'SELECT d.messageid ' . $query[0];
 
         try {
             return $this->_db->selectValue($query[0], $query[1]);
