@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -16,18 +16,35 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
 class Horde_Imap_Client_Data_Format_Filter_Quote extends php_user_filter
 {
+    /**
+     * Has the initial quote been prepended?
+     *
+     * @var boolean
+     */
+    protected $_prepend;
+
+    /**
+     */
+    public function onCreate()
+    {
+        $this->_prepend = false;
+    }
+
     /**
      * @see stream_filter_register()
      */
     public function filter($in, $out, &$consumed, $closing)
     {
-        stream_bucket_append($out, stream_bucket_new($this->stream, '"'));
+        if (!$this->_prepend) {
+            stream_bucket_append($out, stream_bucket_new($this->stream, '"'));
+            $this->_prepend = true;
+        }
 
         while ($bucket = stream_bucket_make_writeable($in)) {
             $consumed += $bucket->datalen;
@@ -35,7 +52,11 @@ class Horde_Imap_Client_Data_Format_Filter_Quote extends php_user_filter
             stream_bucket_append($out, $bucket);
         }
 
-        stream_bucket_append($out, stream_bucket_new($this->stream, '"'));
+        /* feof() call needed due to:
+         * http://news.php.net/php.internals/80363 */
+        if ($closing || feof($this->stream)) {
+            stream_bucket_append($out, stream_bucket_new($this->stream, '"'));
+        }
 
         return PSFS_PASS_ON;
     }
