@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -16,11 +16,12 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Exception_NoSupportExtension extends Horde_Imap_Client_Exception
+class Horde_Imap_Client_Exception_NoSupportExtension
+extends Horde_Imap_Client_Exception
 {
     /**
      * The extension not supported on the server.
@@ -41,7 +42,10 @@ class Horde_Imap_Client_Exception_NoSupportExtension extends Horde_Imap_Client_E
         $this->extension = $extension;
 
         if (is_null($msg)) {
-            $msg = sprintf(Horde_Imap_Client_Translation::t("The server does not support the %s extension."), $extension);
+            $msg = sprintf(
+                Horde_Imap_Client_Translation::r("The server does not support the %s extension."),
+                $extension
+            );
         }
 
         parent::__construct($msg, self::NOT_SUPPORTED);
