@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -17,11 +17,12 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Exception_SearchCharset extends Horde_Imap_Client_Exception
+class Horde_Imap_Client_Exception_SearchCharset
+extends Horde_Imap_Client_Exception
 {
     /**
      * Charset that was attempted to be converted to.
@@ -41,7 +42,7 @@ class Horde_Imap_Client_Exception_SearchCharset extends Horde_Imap_Client_Except
         $this->charset = $charset;
 
         parent::__construct(
-            Horde_Imap_Client_Translation::t("Cannot convert search query text to new charset"),
+            Horde_Imap_Client_Translation::r("Cannot convert search query text to new charset"),
             self::BADCHARSET
         );
     }
