@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -104,8 +104,8 @@ class Horde_Imap_Client_Fetch_Query implements ArrayAccess, Countable, Iterator
     /**
      * Return MIME header text.
      *
-     *  MIME header text is defined only for non-RFC 2822 messages and
-     *  non-message/rfc822 parts.
+     * MIME header text is defined only for non-RFC 2822 messages and
+     * non-message/rfc822 parts.
      *
      * @param string $id   The MIME ID to obtain the MIME header text for.
      * @param array $opts  The following options are available:
@@ -184,9 +184,12 @@ class Horde_Imap_Client_Fetch_Query implements ArrayAccess, Countable, Iterator
      */
     public function headers($label, $search, array $opts = array())
     {
-        $this->_data[Horde_Imap_Client::FETCH_HEADERS][$label] = array_merge($opts, array(
-            'headers' => $search
-        ));
+        $this->_data[Horde_Imap_Client::FETCH_HEADERS][$label] = array_merge(
+            $opts,
+            array(
+                'headers' => array_map('strval', $search)
+            )
+        );
     }
 
     /**
@@ -286,13 +289,13 @@ class Horde_Imap_Client_Fetch_Query implements ArrayAccess, Countable, Iterator
     }
 
     /**
-     * Returns a MD5 hash of the current query object.
+     * Returns a hash of the current query object.
      *
-     * @return string  MD5 hash.
+     * @return string  Hash.
      */
     public function hash()
     {
-        return hash('sha1', serialize($this));
+        return hash('md5', serialize($this));
     }
 
     /* ArrayAccess methods. */
