@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -16,11 +16,12 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Interaction_Server_Tagged extends Horde_Imap_Client_Interaction_Server
+class Horde_Imap_Client_Interaction_Server_Tagged
+extends Horde_Imap_Client_Interaction_Server
 {
     /**
      * Tag.
@@ -39,7 +40,9 @@ class Horde_Imap_Client_Interaction_Server_Tagged extends Horde_Imap_Client_Inte
         parent::__construct($token);
 
         if (is_null($this->status)) {
-            throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Bad tagged response."));
+            throw new Horde_Imap_Client_Exception(
+                Horde_Imap_Client_Translation::r("Bad tagged response.")
+            );
         }
     }
 
