@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2009-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -43,7 +43,7 @@
  *
  * @category  Horde
  * @copyright 2002 Richard Heyes
- * @copyright 2009-2014 Horde LLC
+ * @copyright 2009-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -64,6 +64,7 @@
  *   - RFC 3206: AUTH/SYS response codes
  *   - RFC 4616: AUTH=PLAIN
  *   - RFC 5034: POP3 SASL
+ *   - RFC 5802: AUTH=SCRAM-SHA-1
  *   - RFC 6856: UTF8, LANG
  * </pre>
  *
@@ -71,7 +72,7 @@
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
  * @copyright 2002 Richard Heyes
- * @copyright 2009-2014 Horde LLC
+ * @copyright 2009-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -189,13 +190,6 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
         throw new Horde_Imap_Client_Exception_NoSupportPop3('Namespaces');
     }
 
-    /**
-     */
-    public function alerts()
-    {
-        return array();
-    }
-
     /**
      */
     protected function _login()
@@ -320,6 +314,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
                 $this->getParam('port'),
                 $this->getParam('timeout'),
                 $this->getParam('secure'),
+                $this->getParam('context'),
                 array(
                     'debug' => $this->_debug
                 )
@@ -360,7 +355,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             // RFC 5034: CRAM-MD5
             // CRAM-SHA1 & CRAM-SHA256 supported by Courier SASL library
             $challenge = $this->_sendLine('AUTH ' . $method);
-            $response = base64_encode($username . ' ' . hash_hmac(strtolower(substr($method, 5)), base64_decode(substr($challenge['resp'], 2)), $password, true));
+            $response = base64_encode($username . ' ' . hash_hmac(Horde_String::lower(substr($method, 5)), base64_decode(substr($challenge['resp'], 2)), $password, true));
             $this->_sendLine($response, array(
                 'debug' => sprintf('[AUTH Response (username: %s)]', $username)
             ));
@@ -425,8 +420,16 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
                     $saslprep = new Znerol\Component\Stringprep\Profile\SASLprep();
 
                     try {
-                        $username = $saslprep->apply($username, 'UTF-8', self::MODE_QUERY);
-                        $password = $saslprep->apply($password, 'UTF-8', self::MODE_STORE);
+                        $username = $saslprep->apply(
+                            $username,
+                            'UTF-8',
+                            Znerol\Compnonent\Stringprep\Profile::MODE_QUERY
+                        );
+                        $password = $saslprep->apply(
+                            $password,
+                            'UTF-8',
+                            Znerol\Compnonent\Stringprep\Profile::MODE_STORE
+                        );
                         $error = false;
                     } catch (Znerol\Component\Stringprep\ProfileException $e) {
                         $error = true;
@@ -466,6 +469,50 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             ));
             break;
 
+        case 'SCRAM-SHA-1':
+            $scram = new Horde_Imap_Client_Auth_Scram(
+                $username,
+                $password,
+                'SHA1'
+            );
+
+            $c1 = $this->_sendLine(
+                'AUTH ' . $method . ' ' . base64_encode($scram->getClientFirstMessage())
+            );
+
+            $sr1 = base64_decode(substr($c1['resp'], 2));
+            if (!$scram->parseServerFirstMessage($sr1)) {
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Authentication failed."),
+                    Horde_Imap_Client_Exception::LOGIN_AUTHENTICATIONFAILED
+                );
+            }
+
+            $c2 = $this->_sendLine(
+                base64_encode($scram->getClientFinalMessage())
+            );
+
+            $sr2 = base64_decode(substr($c2['resp'], 2));
+            if (!$scram->parseServerFirstMessage($sr)) {
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Authentication failed."),
+                    Horde_Imap_Client_Exception::LOGIN_AUTHENTICATIONFAILED
+                );
+
+                /* This means authentication passed, according to the server,
+                 * but the server signature is incorrect. This indicates that
+                 * server verification has failed. Immediately disconnect from
+                 * the server, since this is a possible security issue. */
+                $this->logout();
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Server failed verification check."),
+                    Horde_Imap_Client_Exception::LOGIN_SERVER_VERIFICATION_FAILED
+                );
+            }
+
+            $this->_sendLine('');
+            break;
+
         default:
             $e = new Horde_Imap_Client_Exception(
                 Horde_Imap_Client_Translation::r("Unknown authentication method: %s"),
@@ -610,13 +657,17 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
      */
     protected function _listMailboxes($pattern, $mode, $options)
     {
-        return array(
-            'INBOX' => array(
-                'attributes' => array(),
-                'delimiter' => '',
-                'mailbox' => Horde_Imap_Client_Mailbox::get('INBOX')
-            )
-        );
+        if (empty($options['flat'])) {
+            return array(
+                'INBOX' => array(
+                    'attributes' => array(),
+                    'delimiter' => '',
+                    'mailbox' => Horde_Imap_Client_Mailbox::get('INBOX')
+                )
+            );
+        }
+
+        return array('INBOX' => Horde_Imap_Client_Mailbox::get('INBOX'));
     }
 
     /**
@@ -649,7 +700,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
         $uidl = $this->_capability('UIDL');
         if ($flags & Horde_Imap_Client::STATUS_UIDNEXT) {
             if ($uidl) {
-                $ctx = hash_init((PHP_MINOR_VERSION >= 4) ? 'fnv132' : 'sha1');
+                $ctx = hash_init('md5');
                 foreach ($this->_pop3Cache('uidl') as $key => $val) {
                     hash_update($ctx, '|' . $key . '|' . $val);
                 }
@@ -902,12 +953,12 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
                             $tmp2 = $tmp->toArray(array('nowrap' => true));
                             foreach (array_keys($tmp2) as $hdr) {
                                 if (!in_array($hdr, $val['headers'])) {
-                                    $tmp->removeHeader($hdr);
+                                    unset($tmp[$hdr]);
                                 }
                             }
                         } else {
                             foreach ($val['headers'] as $hdr) {
-                                $tmp->removeHeader($hdr);
+                                unset($tmp[$hdr]);
                             }
                         }
 
@@ -930,16 +981,16 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
                 foreach ($seq_ids as $id) {
                     $tmp = $this->_pop3Cache('hdrob', $id);
                     $results->get($lookup[$id])->setEnvelope(array(
-                        'date' => $tmp->getValue('date'),
-                        'subject' => $tmp->getValue('subject'),
-                        'from' => $tmp->getOb('from'),
-                        'sender' => $tmp->getOb('sender'),
-                        'reply_to' => $tmp->getOb('reply-to'),
-                        'to' => $tmp->getOb('to'),
-                        'cc' => $tmp->getOb('cc'),
-                        'bcc' => $tmp->getOb('bcc'),
-                        'in_reply_to' => $tmp->getValue('in-reply-to'),
-                        'message_id' => $tmp->getValue('message-id')
+                        'date' => $tmp['Date'],
+                        'subject' => $tmp['Subject'],
+                        'from' => ($h = $tmp['From']) ? $h->getAddressList(true) : null,
+                        'sender' => ($h = $tmp['Sender']) ? $h->getAddressList(true) : null,
+                        'reply_to' => ($h = $tmp['Reply-to']) ? $h->getAddressList(true) : null,
+                        'to' => ($h = $tmp['To']) ? $h->getAddressList(true) : null,
+                        'cc' => ($h = $tmp['Cc']) ? $h->getAddressList(true) : null,
+                        'bcc' => ($h = $tmp['Bcc']) ? $h->getAddressList(true) : null,
+                        'in_reply_to' => $tmp['In-Reply-To'],
+                        'message_id' => $tmp['Message-ID']
                     ));
                 }
                 break;
@@ -947,7 +998,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             case Horde_Imap_Client::FETCH_IMAPDATE:
                 foreach ($seq_ids as $id) {
                     $tmp = $this->_pop3Cache('hdrob', $id);
-                    $results->get($lookup[$id])->setImapDate($tmp->getValue('date'));
+                    $results->get($lookup[$id])->setImapDate($tmp['Date']);
                 }
                 break;
 
@@ -1476,9 +1527,9 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             $pos = strpos($text, ' ', 2);
             $end_pos = strpos($text, ']', 2);
             if ($pos > $end_pos) {
-                $ret->code = strtoupper(substr($text, 1, $end_pos - 1));
+                $ret->code = Horde_String::upper(substr($text, 1, $end_pos - 1));
             } else {
-                $ret->code = strtoupper(substr($text, 1, $pos - 1));
+                $ret->code = Horde_String::upper(substr($text, 1, $pos - 1));
                 $ret->data = substr($text, $pos + 1, $end_pos - $pos - 1);
             }
             $ret->text = trim(substr($text, $end_pos + 1));
