@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2013-2014 Horde LLC
+ * @copyright  2013-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2013-2014 Horde LLC
+ * @copyright  2013-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
@@ -31,10 +31,10 @@ class Horde_Imap_Client_Cache_MongoTest extends Horde_Imap_Client_Cache_TestBase
     protected function _getBackend()
     {
         if (($config = self::getConfig('IMAPCLIENT_TEST_CONFIG', __DIR__ . '/..')) &&
-            isset($config['imapclient']['mongo'])) {
+            isset($config['mongo'])) {
             $factory = new Horde_Test_Factory_Mongo();
             $this->_mongo = $factory->create(array(
-                'config' => $config['imapclient']['mongo'],
+                'config' => $config['mongo'],
                 'dbname' => $this->_dbname
             ));
         }
