@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
@@ -53,4 +53,35 @@ class Horde_Imap_Client_DateTimeTest extends PHPUnit_Framework_TestCase
         );
     }
 
+    public function testClone()
+    {
+        $ob = new Horde_Imap_Client_DateTime('12 Sep 2007 15:49:12 UTC');
+
+        $ob2 = clone $ob;
+
+        $ob2->modify('+1 minute');
+
+        $this->assertEquals(
+            1189612152,
+            intval(strval($ob))
+        );
+
+        $this->assertEquals(
+            1189612152 + 60,
+            intval(strval($ob2))
+        );
+    }
+
+    public function testSerialize()
+    {
+        $ob = new Horde_Imap_Client_DateTime('12 Sep 2007 15:49:12 UTC');
+
+        $ob2 = unserialize(serialize($ob));
+
+        $this->assertEquals(
+            1189612152,
+            intval(strval($ob2))
+        );
+    }
+
 }
