@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
@@ -330,4 +330,33 @@ class Horde_Imap_Client_IdsTest extends PHPUnit_Framework_TestCase
         );
     }
 
+    public function testClone()
+    {
+        $ids = new Horde_Imap_Client_Ids(array(1, 3));
+
+        $ids2 = clone $ids;
+        $ids2->add(5);
+
+        $this->assertEquals(
+            array(1, 3),
+            iterator_to_array($ids)
+        );
+        $this->assertEquals(
+            array(1, 3, 5),
+            iterator_to_array($ids2)
+        );
+    }
+
+    public function testSerialize()
+    {
+        $ids = new Horde_Imap_Client_Ids(array(1, 3, 5));
+
+        $ids2 = unserialize(serialize($ids));
+
+        $this->assertEquals(
+            array(1, 3, 5),
+            iterator_to_array($ids2)
+        );
+    }
+
 }
