@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2013-2014 Horde LLC
+ * @copyright  2013-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2013-2014 Horde LLC
+ * @copyright  2013-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
@@ -25,6 +25,9 @@
  */
 class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
 {
+    const DEFAULT_MBOX = '_____TestMailboxTest';
+    const DEFAULT_MBOX_UTF8 = '_____TestMailboxTest1è';
+
     public static $config;
 
     private static $created;
@@ -36,8 +39,12 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
         $c = array_shift(self::$config);
 
         self::$created = false;
-        self::$test_mbox = $c['test_mbox'];
-        self::$test_mbox_utf8 = $c['test_mbox_utf8'];
+        self::$test_mbox = isset($c['test_mbox'])
+            ? $c['test_mbox']
+            : self::DEFAULT_MBOX;
+        self::$test_mbox_utf8 = isset($c['test_mbox_utf8'])
+            ? $c['test_mbox_utf8']
+            : self::DEFAULT_MBOX_UTF8;
 
         try {
             $c['client_config']['cache'] = array(
@@ -316,6 +323,16 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
             Horde_Imap_Client::STATUS_FIRSTUNSEEN | Horde_Imap_Client::STATUS_FLAGS | Horde_Imap_Client::STATUS_PERMFLAGS | Horde_Imap_Client::STATUS_HIGHESTMODSEQ | Horde_Imap_Client::STATUS_UIDNOTSTICKY
         );
         $this->assertInternalType('array', $s);
+
+        // Github Issue #134 (UTF8 mailbox)
+        $s = self::$live->status(
+            self::$test_mbox_utf8,
+            Horde_Imap_Client::STATUS_MESSAGES
+        );
+        $this->assertEquals(
+            0,
+            $s['messages']
+        );
     }
 
     /**
@@ -555,7 +572,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
 
         try {
             $this->assertEquals(
-                array(3, 1, 4, 2),
+                array(3, 4, 1, 2),
                 $res['match']->ids
             );
         } catch (Exception $e) {
