@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
@@ -25,6 +25,18 @@
  */
 class Horde_Imap_Client_MailboxTest extends PHPUnit_Framework_TestCase
 {
+    public function testMailboxClone()
+    {
+        $ob = new Horde_Imap_Client_Mailbox('Envoyé');
+
+        $ob2 = clone $ob;
+
+        $this->assertEquals(
+            'Envoyé',
+            $ob2->utf8
+        );
+     }
+
     public function testMailboxSerialize()
     {
         $mailbox = unserialize(
@@ -106,4 +118,33 @@ class Horde_Imap_Client_MailboxTest extends PHPUnit_Framework_TestCase
         );
     }
 
+    public function testBug13825()
+    {
+        $mbox = 'INBOX.!  Astrid"';
+        $mbox_escape = '"INBOX.!  Astrid\""';
+
+        $ob = new Horde_Imap_Client_Mailbox($mbox);
+
+        $this->assertEquals(
+            $ob,
+            Horde_Imap_Client_Mailbox::get($mbox)
+        );
+        $this->assertEquals(
+            $ob,
+            Horde_Imap_Client_Mailbox::get($ob)
+        );
+
+        $format = new Horde_Imap_Client_Data_Format_Mailbox($ob);
+        $this->assertEquals(
+            $mbox_escape,
+            $format->escape()
+        );
+
+        $format2 = new Horde_Imap_Client_Data_Format_Mailbox_Utf8($ob);
+        $this->assertEquals(
+            $mbox_escape,
+            $format2->escape()
+        );
+    }
+
 }
