@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2011-2014 Horde LLC
+ * @copyright  2011-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Imap_Client
@@ -94,8 +94,37 @@ class Horde_Imap_Client_MapTest extends PHPUnit_Framework_TestCase
         );
     }
 
+    public function testCount()
+    {
+        $this->assertEquals(
+            6,
+            count($this->map)
+        );
+    }
+
+    /**
+     * @depends testCount
+     */
+    public function testClone()
+    {
+        $map2 = clone $this->map;
+        $map2->update(array(
+            1 => 1
+        ));
+
+        $this->assertEquals(
+            6,
+            count($this->map)
+        );
+        $this->assertEquals(
+            7,
+            count($map2)
+        );
+    }
+
     /**
      * @dataProvider lookupProvider
+     * @depends testClone
      */
     public function testLookup($range, $expected = null)
     {
@@ -134,6 +163,7 @@ class Horde_Imap_Client_MapTest extends PHPUnit_Framework_TestCase
 
     /**
      * @dataProvider removeProvider
+     * @depends testClone
      */
     public function testRemove($range, $expected)
     {
@@ -221,14 +251,6 @@ class Horde_Imap_Client_MapTest extends PHPUnit_Framework_TestCase
         );
     }
 
-    public function testCount()
-    {
-        $this->assertEquals(
-            6,
-            count($this->map)
-        );
-    }
-
     public function testIterator()
     {
         $this->assertEquals(
